@@ -14,12 +14,12 @@ import psutil, tarfile
 import glob
 import pandas as pd
 import multiprocessing as mp
-from .isomer_engine import rd_isomer, tautomer_engine
-from .isomer_engine import oe_isomer
-from .ranking import ranking
-from .utils import housekeeping, check_input
-from .utils import hash_taut_smi,  my_name_space
-from .batch_opt.batchopt import optimizing
+from Auto3D.isomer_engine import rd_isomer, tautomer_engine
+from Auto3D.isomer_engine import oe_isomer
+from Auto3D.ranking import ranking
+from Auto3D.utils import housekeeping, check_input
+from Auto3D.utils import hash_taut_smi,  my_name_space
+from Auto3D.batch_opt.batchopt import optimizing
 from send2trash import send2trash
 try:
     mp.set_start_method('spawn')
@@ -159,25 +159,29 @@ def optim_rank_wrapper(args, queue):
 def options(path, k=False, window=False, verbose=False, job_name="",
     enumerate_tautomer=False, tauto_engine="rdkit",
     isomer_engine="rdkit", cis_trans=True, mode_oe="classic", mpi_np=4, max_confs=1000,
-    use_gpu=True, gpu_idx=0, optimizing_engine="AIMNET",
+    use_gpu=True, gpu_idx=0, capacity=42, optimizing_engine="AIMNET",
     opt_steps=10000, convergence_threshold=0.003, threshold=0.3):
     """Arguments for Auto3D main program
-    path: A input.smi containing SMILES and IDs. Examples are listed in the input folder
+    path: A input.smi containing SMILES and IDs. Examples are listed in the example/files folder
     k: Outputs the top-k structures for each SMILES.
-    window: Outputs the structures whose energies are within window (kcal/mol) from the lowest energy
+    window: Outputs the structures whose energies are within x (kcal/mol) from the lowest energy conformer
     verbose: When True, save all meta data while running.
     job_name: A folder name to save all meta data.
     
     enumerate_tautomer: When True, enumerate tautomers for the input
-    taut_engine: Programs to enumerate tautomers, either 'rdkit' or 'oechem
+    taut_engine: Programs to enumerate tautomers, either 'rdkit' or 'oechem'
     isomer_engine: The program for generating 3D isomers for each SMILES. This parameter is either rdkit or omega.
     cis_trans: When True, cis/trans and r/s isomers are enumerated.
-    mode_oe: "The mode that omega program will take. "It can be either 'classic', 'macrocycle' ""'rocs', 'pose' or 'dense'. "
-                            "By default, the 'classic' mode is used. "
-                            "For detailed information about each mode, see "
-                            "https://docs.eyesopen.com/applications/omega/omega/omega_overview.html"
-    mpi_np: Number of CPU cores for the isomer generation step.
-    max_confs: Maximum number of isomers for each SMILES
+    mode_oe: The mode that omega program will take. It can be either 'classic' or 'macrocycle'. By default, the 'classic' mode is used. For detailed information about each mode, see https://docs.eyesopen.com/applications/omega/omega/omega_overview.html
+    mpi_np: Number of CPU cores for the isomer generation engine.
+    max_confs: Maximum number of isomers for each SMILES.
+    use_gpu: If True, the program will use GPU when available
+    gpu_idx: GPU index. It only works when --use_gpu=True
+    capacity: Number of SMILES that the model will handle for 1 G memory
+    optimizing_engine: Choose either 'ANI2x', 'ANI2xt', or 'AIMNET' for energy calculation and geometry optimization.
+    opt_steps: Maximum optimization steps for each structure.
+    convergence_threshold: Optimization is considered as converged if maximum force is below this threshold.
+    threshold: If the RMSD between two conformers are within threhold, they are considered as duplicates. One of them will be removed.
     """
     d = {}
     args = my_name_space(d)
@@ -194,6 +198,7 @@ def options(path, k=False, window=False, verbose=False, job_name="",
     args["mpi_np"] = mpi_np
     args["max_confs"] = max_confs
     args["use_gpu"] = use_gpu
+    args["capacity"] = capacity
     args["gpu_idx"] = gpu_idx
     args["optimizing_engine"] = optimizing_engine
     args["opt_steps"] = opt_steps
@@ -205,7 +210,7 @@ def main(args:dict):
     """Take the arguments from options and run Auto3D"""
 
 
-    chunk_line = mp.Manager().Queue(4)   #A queue managing two wrappers
+    chunk_line = mp.Manager().Queue(1)   #A queue managing two wrappers
 
 
     start = time.time()
@@ -231,7 +236,7 @@ def main(args:dict):
 
 
     ## Devide jobs based on memory
-    smiles_per_G = 42  #Allow 40 SMILES per GB memory
+    smiles_per_G = args.capacity  #Allow 40 SMILES per GB memory
     if args.use_gpu:
         gpu_idx = int(args.gpu_idx)
         t = int(math.ceil(torch.cuda.get_device_properties(gpu_idx).total_memory/(1024**3)))
@@ -297,7 +302,7 @@ def main(args:dict):
 
 
 if __name__ == "__main__":
-    chunk_line = mp.Manager().Queue(4)   #A queue managing two wrappers
+    chunk_line = mp.Manager().Queue(1)   #A queue managing two wrappers
     print("""
         _              _             _____   ____  
        / \     _   _  | |_    ___   |___ /  |  _ \ 
@@ -354,6 +359,8 @@ if __name__ == "__main__":
                         help="If True, the program will use GPU.")
     parser.add_argument('--gpu_idx', default=0, type=int, 
                         help="GPU index. It only works when --use_gpu=True")
+    parser.add_argument('--capacity', default=42, type=int,
+                        help="Number of SMILES that the model will handle for 1 G memory")
     parser.add_argument('--optimizing_engine', type=str, default='AIMNET',
                         help=("Choose either 'ANI2x', 'ANI2xt', or 'AIMNET' for energy "
                             "calculation and geometry optimization."))
@@ -386,7 +393,7 @@ if __name__ == "__main__":
 
 
     ## Devide jobs based on memory
-    smiles_per_G = 42  #Allow 40 SMILES per GB memory
+    smiles_per_G = args.capacity  #Allow 40 SMILES per GB memory
     if args.use_gpu:
         gpu_idx = int(args.gpu_idx)
         t = int(math.ceil(torch.cuda.get_device_properties(gpu_idx).total_memory/(1024**3)))
